
import './App.css'
import React, { createContext, useEffect, useRef, useState } from "react";
import ReactDom from "react-dom";
import { BrowserRouter, Navigate, Route, Routes } from "react-router-dom";
import {
	DifferencePage,
	DocumentAbout,
	Gallery,
	LoginPage,
	NotFoundPage,
	ProfilePage,
	ReaderPage,
	SettingPage,
	TagsPage,
} from "./page/mod";
import { getInitialValue, UserContext } from "./state";

import "./css/style.css";

const App = () => {
	const [user, setUser] = useState("");
	const [userPermission, setUserPermission] = useState<string[]>([]);
	(async () => {
		const { username, permission } = await getInitialValue();
		if (username !== user) {
			setUser(username);
			setUserPermission(permission);
		}
	})();
	// useEffect(()=>{});
	return (
		<UserContext.Provider
			value={{
				username: user,
				setUsername: setUser,
				permission: userPermission,
				setPermission: setUserPermission,
			}}
		>
				<BrowserRouter>
					<Routes>
						<Route path="/" element={<Navigate replace to="/search?" />} />
						<Route path="/search" element={<Gallery />} />
						<Route path="/doc/:id" element={<DocumentAbout />}></Route>
						<Route path="/doc/:id/reader" element={<ReaderPage />}></Route>
						<Route path="/login" element={<LoginPage></LoginPage>} />
						<Route path="/profile" element={<ProfilePage />}></Route>
						<Route path="/difference" element={<DifferencePage />}></Route>
						<Route path="/setting" element={<SettingPage />}></Route>
						<Route path="/tags" element={<TagsPage />}></Route>
						<Route path="*" element={<NotFoundPage />} />
					</Routes>
				</BrowserRouter>
		</UserContext.Provider>
	);
};

export default App
