import {
	ArrowBack as ArrowBackIcon,
	Collections as CollectionIcon,
	Folder as FolderIcon,
	Home as HomeIcon,
	List as ListIcon,
	Settings as SettingIcon,
	VideoLibrary as VideoIcon,
} from "@mui/icons-material";
import { Divider, List, ListItem, ListItemIcon, ListItemText, Tooltip } from "@mui/material";
import React from "react";
import { Link as RouterLink } from "react-router-dom";

export const NavItem = (props: { name: string; to: string; icon: React.ReactElement<any, any> }) => {
	return (
		<ListItem button key={props.name} component={RouterLink} to={props.to}>
			<ListItemIcon>
				<Tooltip title={props.name.toLocaleLowerCase()} placement="bottom">
					{props.icon}
				</Tooltip>
			</ListItemIcon>
			<ListItemText primary={props.name}></ListItemText>
		</ListItem>
	);
};

export const NavList = (props: { children?: React.ReactNode }) => {
	return <List>{props.children}</List>;
};

export const BackItem = (props: { to?: string }) => {
	return <NavItem name="Back" to={props.to ?? "/"} icon={<ArrowBackIcon></ArrowBackIcon>} />;
};

export function CommonMenuList(props?: { url?: string }) {
	let url = props?.url ?? "";
	return (
		<NavList>
			{url !== "" && (
				<>
					<BackItem to={url} /> <Divider />
				</>
			)}
			<NavItem name="All" to="/" icon={<HomeIcon />} />
			<NavItem name="Comic" to="/search?content_type=comic" icon={<CollectionIcon />}></NavItem>
			<NavItem name="Video" to="/search?content_type=video" icon={<VideoIcon />} />
			<Divider />
			<NavItem name="Tags" to="/tags" icon={<ListIcon />} />
			<Divider />
			<NavItem name="Difference" to="/difference" icon={<FolderIcon />}></NavItem>
			<NavItem name="Settings" to="/setting" icon={<SettingIcon />} />
		</NavList>
	);
}
