import * as colors from "@mui/material/colors";
import Chip, { ChipTypeMap } from "@mui/material/Chip";
import { emphasize, styled, Theme, useTheme } from "@mui/material/styles";
import React from "react";
import { Link as RouterLink } from "react-router-dom";

type TagChipStyleProp = {
	color: `rgba(${number},${number},${number},${number})` | `#${string}` | "default";
};

const { blue, pink } = colors;
const getTagColorName = (tagname: string): TagChipStyleProp["color"] => {
	if (tagname.startsWith("female")) {
		return pink[600];
	} else if (tagname.startsWith("male")) {
		return blue[600];
	} else return "default";
};

type ColorChipProp = Omit<ChipTypeMap["props"], "color"> &
	TagChipStyleProp & {
		component?: React.ElementType;
		to?: string;
	};

export const ColorChip = (props: ColorChipProp) => {
	const { color, ...rest } = props;
	const theme = useTheme();

	let newcolor = color;
	if (color === "default") {
		newcolor = "#ebebeb";
	}
	return (
		<Chip
			sx={{
				color: theme.palette.getContrastText(newcolor),
				backgroundColor: newcolor,
				["&:hover, &:focus"]: {
					backgroundColor: emphasize(newcolor, 0.08),
				},
			}}
			{...rest}
		></Chip>
	);
};

type TagChipProp = Omit<ChipTypeMap["props"], "color"> & {
	tagname: string;
};

export const TagChip = (props: TagChipProp) => {
	const { tagname, label, clickable, ...rest } = props;
	const colorName = getTagColorName(tagname);

	let newlabel: React.ReactNode = label;
	if (typeof label === "string") {
		const female = "female:";
		const male = "male:";
		if (label.startsWith(female)) {
			newlabel = "♀ " + label.slice(female.length);
		} else if (label.startsWith(male)) {
			newlabel = "♂ " + label.slice(male.length);
		}
	}

	const inner = clickable ? (
		<ColorChip
			color={colorName}
			clickable={clickable}
			label={newlabel ?? label}
			{...rest}
			component={RouterLink}
			to={`/search?allow_tag=${tagname}`}
		/>
	) : (
		<ColorChip color={colorName} clickable={clickable} label={newlabel ?? label} {...rest} />
	);
	return inner;
};
