import { Box, Button, Paper, Typography } from "@mui/material";
import React, { useContext, useEffect, useState } from "react";
import { CommonMenuList, Headline } from "../component/mod";
import { UserContext } from "../state";
import { PagePad } from "../component/pagepad";

type FileDifference = {
	type: string;
	value: {
		type: string;
		path: string;
	}[];
};

function TypeDifference(prop: {
	content: FileDifference;
	onCommit: (v: { type: string; path: string }) => void;
	onCommitAll: (type: string) => void;
}) {
	// const classes = useStyles();
	const x = prop.content;
	const [button_disable, set_disable] = useState(false);

	return (
		<Paper /*className={classes.paper}*/>
			<Box /*className={classes.contentTitle}*/>
				<Typography variant="h3">{x.type}</Typography>
				<Button
					variant="contained"
					key={x.type}
					onClick={() => {
						set_disable(true);
						prop.onCommitAll(x.type);
						set_disable(false);
					}}
				>
					Commit all
				</Button>
			</Box>
			{x.value.map((y) => (
				<Box sx={{ display: "flex" }} key={y.path}>
					<Button
						variant="contained"
						onClick={() => {
							set_disable(true);
							prop.onCommit(y);
							set_disable(false);
						}}
						disabled={button_disable}
					>
						Commit
					</Button>
					<Typography variant="h5">{y.path}</Typography>
				</Box>
			))}
		</Paper>
	);
}

export function DifferencePage() {
	const ctx = useContext(UserContext);
	// const classes = useStyles();
	const [diffList, setDiffList] = useState<FileDifference[]>([]);
	const doLoad = async () => {
		const list = await fetch("/api/diff/list");
		if (list.ok) {
			const inner = await list.json();
			setDiffList(inner);
		} else {
			// setDiffList([]);
		}
	};
	const Commit = async (x: { type: string; path: string }) => {
		const res = await fetch("/api/diff/commit", {
			method: "POST",
			body: JSON.stringify([{ ...x }]),
			headers: {
				"content-type": "application/json",
			},
		});
		const bb = await res.json();
		if (bb.ok) {
			doLoad();
		} else {
			console.error("fail to add document");
		}
	};
	const CommitAll = async (type: string) => {
		const res = await fetch("/api/diff/commitall", {
			method: "POST",
			body: JSON.stringify({ type: type }),
			headers: {
				"content-type": "application/json",
			},
		});
		const bb = await res.json();
		if (bb.ok) {
			doLoad();
		} else {
			console.error("fail to add document");
		}
	};
	useEffect(() => {
		doLoad();
		const i = setInterval(doLoad, 5000);
		return () => {
			clearInterval(i);
		};
	}, []);
	const menu = CommonMenuList();
	return (
		<Headline menu={menu}>
			<PagePad>
				{ctx.username == "admin" ? (
					<div>
						{diffList.map((x) => (
							<TypeDifference key={x.type} content={x} onCommit={Commit} onCommitAll={CommitAll} />
						))}
					</div>
				) : (
					<Typography variant="h2">Not Allowed : please login as an admin</Typography>
				)}
			</PagePad>
		</Headline>
	);
}
